==> insighttoolkit4_4.5.0.orig.tar.xz: InsightToolkit-4.5.0/Modules/Filtering/FastMarching/test/itkFastMarchingThresholdStoppingCriterionTest.cxx <==
/*=========================================================================
 *
 *  Copyright Insight Software Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/

#include "itkFastMarchingThresholdStoppingCriterion.h"

int itkFastMarchingThresholdStoppingCriterionTest( int , char * [] )
{
  typedef itk::Image< float, 2> ImageType;

  typedef itk::FastMarchingThresholdStoppingCriterion<
      ImageType, ImageType > ImageStoppingCriterionType;

  ImageStoppingCriterionType::Pointer image_criterion = ImageStoppingCriterionType::New();
  if( image_criterion.IsNull() )
    {
    return EXIT_FAILURE;
    }

  typedef itk::QuadEdgeMesh< float, 3 > MeshType;

  typedef itk::FastMarchingThresholdStoppingCriterion< MeshType, MeshType >
      MeshStoppingCriterionType;

  MeshStoppingCriterionType::Pointer mesh_criterion = MeshStoppingCriterionType::New();
  if( mesh_criterion.IsNull() )
    {
    return EXIT_FAILURE;
    }

  return EXIT_SUCCESS;
}

==> insighttoolkit5_5.2.1.orig.tar.xz: InsightToolkit-5.2.1/Modules/Filtering/FastMarching/test/itkFastMarchingThresholdStoppingCriterionTest.cxx <==
/*=========================================================================
 *
 *  Copyright NumFOCUS
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0.txt
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *=========================================================================*/

#include "itkFastMarchingThresholdStoppingCriterion.h"

int
itkFastMarchingThresholdStoppingCriterionTest(int, char *[])
{
  using ImageType = itk::Image<float, 2>;

  using ImageStoppingCriterionType = itk::FastMarchingThresholdStoppingCriterion<ImageType, ImageType>;

  ImageStoppingCriterionType::Pointer image_criterion = ImageStoppingCriterionType::New();
  if (image_criterion.IsNull())
  {
    return EXIT_FAILURE;
  }

  using MeshType = itk::QuadEdgeMesh<float, 3>;

  using MeshStoppingCriterionType = itk::FastMarchingThresholdStoppingCriterion<MeshType, MeshType>;

  MeshStoppingCriterionType::Pointer mesh_criterion = MeshStoppingCriterionType::New();
  if (mesh_criterion.IsNull())
  {
    return EXIT_FAILURE;
  }

  return EXIT_SUCCESS;
}
